@@ -229,7 +229,6 @@ alarm_settings_update_sound (AlarmSettingsDialog *dialog)
 	AlarmListEntry *item;
 	GList *l;
 	gint pos;
-	gint sound_pos = -1;
 
 	pos = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->notify_sound_combo));
 	item = g_list_nth_data (dialog->applet->sounds, pos);
@@ -250,7 +249,6 @@ alarm_settings_update_sound (AlarmSettingsDialog *dialog)
 		item = (AlarmListEntry *)l->data;
 		if (strcmp (item->data, dialog->alarm->sound_file) == 0) {
 			// Match!
-			sound_pos = pos;
 			gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->notify_sound_combo), pos);
 			break;
 		}
@@ -461,26 +459,29 @@ void
 alarm_settings_changed_type (GtkToggleButton *toggle, gpointer data)
 {
     AlarmApplet *applet = (AlarmApplet *)data;
-	AlarmSettingsDialog *dialog = applet->settings_dialog;
-    
-	GtkWidget *toggle2 = (GTK_WIDGET (toggle) == dialog->clock_toggle) ? dialog->timer_toggle : dialog->clock_toggle;
-	gboolean toggled = gtk_toggle_button_get_active(toggle);
+    AlarmSettingsDialog *dialog = applet->settings_dialog;
+    gboolean toggled = gtk_toggle_button_get_active(toggle);
 
     g_assert (dialog->alarm != NULL);
-    g_debug ("alarm_settings_changed_type");
-	
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle2), !toggled);
-	
-	if (GTK_WIDGET (toggle) == dialog->clock_toggle && toggled) {
-		g_object_set (dialog->alarm, "type", ALARM_TYPE_CLOCK, NULL);
-        gtk_widget_set_sensitive(dialog->repeat_expand, TRUE);
-	} else {
-		g_object_set (dialog->alarm, "type", ALARM_TYPE_TIMER, NULL);
-        gtk_widget_set_sensitive(dialog->repeat_expand, FALSE);
-	}
-    
-    // TODO: Why?
-//	alarm_settings_changed_time (GTK_SPIN_BUTTON (dialog->hour_spin), dialog);
+    g_debug ("alarm_settings_changed_type(%s) -> %s",
+             gtk_buildable_get_name (GTK_BUILDABLE (toggle)),
+             toggled ? "TRUE" : "FALSE");
+
+    if (GTK_WIDGET (toggle) == dialog->clock_toggle) {
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->timer_toggle), !toggled);
+        if (toggled) {
+            g_debug ("alarm_settings_changed_type: clock toggled");
+            g_object_set (dialog->alarm, "type", ALARM_TYPE_CLOCK, NULL);
+            gtk_widget_set_sensitive(dialog->repeat_expand, TRUE);
+        }
+    } else {
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->clock_toggle), !toggled);
+        if (toggled) {
+            g_debug ("alarm_settings_changed_type: timer toggled");
+            g_object_set (dialog->alarm, "type", ALARM_TYPE_TIMER, NULL);
+            gtk_widget_set_sensitive(dialog->repeat_expand, FALSE);
+        }
+    }
 }
 
 void
@@ -613,12 +614,9 @@ alarm_settings_changed_sound (GtkComboBox *combo, gpointer data)
 
     g_assert (dialog->alarm != NULL);
 	
-	GtkTreeModel *model;
 	AlarmListEntry *item;
-	guint current_index, len, combo_len;
+	guint current_index, len;
 	
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->notify_sound_combo));
-	combo_len = gtk_tree_model_iter_n_children (model, NULL);
 	current_index = gtk_combo_box_get_active (combo);
 	len = g_list_length (dialog->applet->sounds);
 	
@@ -648,7 +646,14 @@ alarm_settings_changed_sound_repeat (GtkToggleButton *togglebutton, gpointer dat
 
     g_assert (dialog->alarm != NULL);
 
+    g_debug("alarm_settings_changed_sound_repeat");
+
     g_object_set (dialog->alarm, "sound-repeat", gtk_toggle_button_get_active (togglebutton), NULL);
+
+    if (dialog->player && dialog->player->state == MEDIA_PLAYER_PLAYING) {
+        // Update preview player
+        dialog->player->loop = gtk_toggle_button_get_active (togglebutton);
+    }
 }
 
 void
@@ -666,12 +671,9 @@ alarm_settings_changed_app (GtkComboBox *combo, gpointer data)
 		return;
 	}
 	
-	GtkTreeModel *model;
 	AlarmListEntry *item;
-	guint current_index, len, combo_len;
+	guint current_index, len;
 	
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->notify_app_combo));
-	combo_len = gtk_tree_model_iter_n_children (model, NULL);
 	current_index = gtk_combo_box_get_active (combo);
 	len = g_list_length (dialog->applet->apps);
 	
@@ -797,6 +799,10 @@ alarm_settings_dialog_close (AlarmSettingsDialog *dialog)
 	
 //	gtk_widget_destroy (GTK_WIDGET (dialog->dialog))
 	
+
+    /* Enable the alarm when closing the dialog */
+    alarm_enable (dialog->alarm);
+
     alarm_settings_dialog_clear (dialog);
 
     gtk_widget_hide (dialog->dialog);
